Class: Aws::AppRegistry::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppRegistry::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appregistry/client.rb,
sig/client.rbs
Overview
An API client for AppRegistry. To construct a client, you need to configure a :region and :credentials.
client = Aws::AppRegistry::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateAttributeGroupResponseSuccess, _AssociateResourceResponseSuccess, _CreateApplicationResponseSuccess, _CreateAttributeGroupResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteAttributeGroupResponseSuccess, _DisassociateAttributeGroupResponseSuccess, _DisassociateResourceResponseSuccess, _GetApplicationResponseSuccess, _GetAssociatedResourceResponseSuccess, _GetAttributeGroupResponseSuccess, _GetConfigurationResponseSuccess, _ListApplicationsResponseSuccess, _ListAssociatedAttributeGroupsResponseSuccess, _ListAssociatedResourcesResponseSuccess, _ListAttributeGroupsForApplicationResponseSuccess, _ListAttributeGroupsResponseSuccess, _ListTagsForResourceResponseSuccess, _SyncResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateAttributeGroupResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_attribute_group(params = {}) ⇒ Types::AssociateAttributeGroupResponse
Associates an attribute group with an application to augment the application's metadata with the group's attributes.
-
#associate_resource(params = {}) ⇒ Types::AssociateResourceResponse
Associates a resource with an application.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions.
-
#create_attribute_group(params = {}) ⇒ Types::CreateAttributeGroupResponse
Creates a new attribute group as a container for user-defined attributes.
-
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an application that is specified either by its application ID, name, or ARN.
-
#delete_attribute_group(params = {}) ⇒ Types::DeleteAttributeGroupResponse
Deletes an attribute group, specified either by its attribute group ID, name, or ARN.
-
#disassociate_attribute_group(params = {}) ⇒ Types::DisassociateAttributeGroupResponse
Disassociates an attribute group from an application to remove the extra attributes contained in the attribute group from the application's metadata.
-
#disassociate_resource(params = {}) ⇒ Types::DisassociateResourceResponse
Disassociates a resource from application.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves metadata information about one of your applications.
-
#get_associated_resource(params = {}) ⇒ Types::GetAssociatedResourceResponse
Gets the resource associated with the application.
-
#get_attribute_group(params = {}) ⇒ Types::GetAttributeGroupResponse
Retrieves an attribute group by its ARN, ID, or name.
-
#get_configuration(params = {}) ⇒ Types::GetConfigurationResponse
Retrieves a
TagKeyconfiguration from an account. -
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Retrieves a list of all of your applications.
-
#list_associated_attribute_groups(params = {}) ⇒ Types::ListAssociatedAttributeGroupsResponse
Lists all attribute groups that are associated with specified application.
-
#list_associated_resources(params = {}) ⇒ Types::ListAssociatedResourcesResponse
Lists all of the resources that are associated with the specified application.
-
#list_attribute_groups(params = {}) ⇒ Types::ListAttributeGroupsResponse
Lists all attribute groups which you have access to.
-
#list_attribute_groups_for_application(params = {}) ⇒ Types::ListAttributeGroupsForApplicationResponse
Lists the details of all attribute groups associated with a specific application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags on the resource.
-
#put_configuration(params = {}) ⇒ Struct
Associates a
TagKeyconfiguration to an account. -
#sync_resource(params = {}) ⇒ Types::SyncResourceResponse
Syncs the resource with current AppRegistry records.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing application with new attributes.
-
#update_attribute_group(params = {}) ⇒ Types::UpdateAttributeGroupResponse
Updates an existing attribute group with new details.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appregistry/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1629 1630 1631 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1629 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1632 1633 1634 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1632 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_attribute_group(params = {}) ⇒ Types::AssociateAttributeGroupResponse
Associates an attribute group with an application to augment the application's metadata with the group's attributes. This feature enables applications to be described with user-defined details that are machine-readable, such as third-party integrations.
87 |
# File 'sig/client.rbs', line 87
def associate_attribute_group: (
|
#associate_resource(params = {}) ⇒ Types::AssociateResourceResponse
Associates a resource with an application. The resource can be specified by its ARN or name. The application can be specified by ARN, ID, or name.
Minimum permissions
You must have the following permissions to associate a resource using
the OPTIONS parameter set to APPLY_APPLICATION_TAG.
-
tag:GetResources -
tag:TagResources
You must also have these additional permissions if you don't use the
AWSServiceCatalogAppRegistryFullAccess policy. For more information,
see AWSServiceCatalogAppRegistryFullAccess in the AppRegistry
Administrator Guide.
-
resource-groups:AssociateResource -
cloudformation:UpdateStack -
cloudformation:DescribeStacks
100 |
# File 'sig/client.rbs', line 100
def associate_resource: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1602 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppRegistry') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appregistry' context[:gem_version] = '1.66.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions.
113 |
# File 'sig/client.rbs', line 113
def create_application: (
|
#create_attribute_group(params = {}) ⇒ Types::CreateAttributeGroupResponse
Creates a new attribute group as a container for user-defined attributes. This feature enables users to have full control over their cloud application's metadata in a rich machine-readable format to facilitate integration with automated workflows and third-party tools.
126 |
# File 'sig/client.rbs', line 126
def create_attribute_group: (
|
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an application that is specified either by its application ID, name, or ARN. All associated attribute groups and resources must be disassociated from it before deleting an application.
140 |
# File 'sig/client.rbs', line 140
def delete_application: (
|
#delete_attribute_group(params = {}) ⇒ Types::DeleteAttributeGroupResponse
Deletes an attribute group, specified either by its attribute group ID, name, or ARN.
150 |
# File 'sig/client.rbs', line 150
def delete_attribute_group: (
|
#disassociate_attribute_group(params = {}) ⇒ Types::DisassociateAttributeGroupResponse
Disassociates an attribute group from an application to remove the
extra attributes contained in the attribute group from the
application's metadata. This operation reverts
AssociateAttributeGroup.
161 |
# File 'sig/client.rbs', line 161
def disassociate_attribute_group: (
|
#disassociate_resource(params = {}) ⇒ Types::DisassociateResourceResponse
Disassociates a resource from application. Both the resource and the application can be specified either by ID or name.
Minimum permissions
You must have the following permissions to remove a resource that's
been associated with an application using the APPLY_APPLICATION_TAG
option for AssociateResource.
-
tag:GetResources -
tag:UntagResources
You must also have the following permissions if you don't use the
AWSServiceCatalogAppRegistryFullAccess policy. For more information,
see AWSServiceCatalogAppRegistryFullAccess in the AppRegistry
Administrator Guide.
-
resource-groups:DisassociateResource -
cloudformation:UpdateStack -
cloudformation:DescribeStacks
173 |
# File 'sig/client.rbs', line 173
def disassociate_resource: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves metadata information about one of your applications. The
application can be specified by its ARN, ID, or name (which is unique
within one account in one region at a given point in time). Specify by
ARN or ID in automated workflows if you want to make sure that the
exact same application is returned or a ResourceNotFoundException is
thrown, avoiding the ABA addressing problem.
194 |
# File 'sig/client.rbs', line 194
def get_application: (
|
#get_associated_resource(params = {}) ⇒ Types::GetAssociatedResourceResponse
Gets the resource associated with the application.
206 |
# File 'sig/client.rbs', line 206
def get_associated_resource: (
|
#get_attribute_group(params = {}) ⇒ Types::GetAttributeGroupResponse
Retrieves an attribute group by its ARN, ID, or name. The attribute group can be specified by its ARN, ID, or name.
229 |
# File 'sig/client.rbs', line 229
def get_attribute_group: (
|
#get_configuration(params = {}) ⇒ Types::GetConfigurationResponse
Retrieves a TagKey configuration from an account.
239 240 |
# File 'sig/client.rbs', line 239
def get_configuration: () -> _GetConfigurationResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetConfigurationResponseSuccess
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Retrieves a list of all of your applications. Results are paginated.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
248 |
# File 'sig/client.rbs', line 248
def list_applications: (
|
#list_associated_attribute_groups(params = {}) ⇒ Types::ListAssociatedAttributeGroupsResponse
Lists all attribute groups that are associated with specified application. Results are paginated.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
260 |
# File 'sig/client.rbs', line 260
def list_associated_attribute_groups: (
|
#list_associated_resources(params = {}) ⇒ Types::ListAssociatedResourcesResponse
Lists all of the resources that are associated with the specified application. Results are paginated.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
273 |
# File 'sig/client.rbs', line 273
def list_associated_resources: (
|
#list_attribute_groups(params = {}) ⇒ Types::ListAttributeGroupsResponse
Lists all attribute groups which you have access to. Results are paginated.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
286 |
# File 'sig/client.rbs', line 286
def list_attribute_groups: (
|
#list_attribute_groups_for_application(params = {}) ⇒ Types::ListAttributeGroupsForApplicationResponse
Lists the details of all attribute groups associated with a specific application. The results display in pages.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
298 |
# File 'sig/client.rbs', line 298
def list_attribute_groups_for_application: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags on the resource.
310 |
# File 'sig/client.rbs', line 310
def list_tags_for_resource: (
|
#put_configuration(params = {}) ⇒ Struct
Associates a TagKey configuration to an account.
316 |
# File 'sig/client.rbs', line 316
def put_configuration: (
|
#sync_resource(params = {}) ⇒ Types::SyncResourceResponse
Syncs the resource with current AppRegistry records.
Specifically, the resource’s AppRegistry system tags sync with its associated application. We remove the resource's AppRegistry system tags if it does not associate with the application. The caller must have permissions to read and update the resource.
332 |
# File 'sig/client.rbs', line 332
def sync_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
Each tag consists of a key and an optional value. If a tag with the same key is already associated with the resource, this action updates its value.
This operation returns an empty response if the call was successful.
342 |
# File 'sig/client.rbs', line 342
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
This operation returns an empty response if the call was successful.
352 |
# File 'sig/client.rbs', line 352
def untag_resource: (
|
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing application with new attributes.
363 |
# File 'sig/client.rbs', line 363
def update_application: (
|
#update_attribute_group(params = {}) ⇒ Types::UpdateAttributeGroupResponse
Updates an existing attribute group with new details.
375 |
# File 'sig/client.rbs', line 375
def update_attribute_group: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1622 1623 1624 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1622 def waiter_names [] end |