Class: Aws::AppRegistry::Types::ResourceInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appregistry/types.rb

Overview

The information about the resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon resource name (ARN) that specifies the resource across services.

Returns:



1218
1219
1220
1221
1222
1223
1224
1225
1226
# File 'lib/aws-sdk-appregistry/types.rb', line 1218

class ResourceInfo < Struct.new(
  :name,
  :arn,
  :resource_type,
  :resource_details,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the resource.

Returns:



1218
1219
1220
1221
1222
1223
1224
1225
1226
# File 'lib/aws-sdk-appregistry/types.rb', line 1218

class ResourceInfo < Struct.new(
  :name,
  :arn,
  :resource_type,
  :resource_details,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#options ⇒ Array<String>

Determines whether an application tag is applied or skipped.

Returns:



1218
1219
1220
1221
1222
1223
1224
1225
1226
# File 'lib/aws-sdk-appregistry/types.rb', line 1218

class ResourceInfo < Struct.new(
  :name,
  :arn,
  :resource_type,
  :resource_details,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#resource_details ⇒ Types::ResourceDetails

The details related to the resource.

Returns:



1218
1219
1220
1221
1222
1223
1224
1225
1226
# File 'lib/aws-sdk-appregistry/types.rb', line 1218

class ResourceInfo < Struct.new(
  :name,
  :arn,
  :resource_type,
  :resource_details,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

Provides information about the Service Catalog App Registry resource type.

Returns:



1218
1219
1220
1221
1222
1223
1224
1225
1226
# File 'lib/aws-sdk-appregistry/types.rb', line 1218

class ResourceInfo < Struct.new(
  :name,
  :arn,
  :resource_type,
  :resource_details,
  :options)
  SENSITIVE = []
  include Aws::Structure
end