Class: Aws::AppRegistry::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppRegistry::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appregistry/client.rb
Overview
An API client for AppRegistry. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AppRegistry::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_attribute_group(params = {}) ⇒ Types::AssociateAttributeGroupResponse
Associates an attribute group with an application to augment the application’s metadata with the group’s attributes.
-
#associate_resource(params = {}) ⇒ Types::AssociateResourceResponse
Associates a resource with an application.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions.
-
#create_attribute_group(params = {}) ⇒ Types::CreateAttributeGroupResponse
Creates a new attribute group as a container for user-defined attributes.
-
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an application that is specified either by its application ID, name, or ARN.
-
#delete_attribute_group(params = {}) ⇒ Types::DeleteAttributeGroupResponse
Deletes an attribute group, specified either by its attribute group ID, name, or ARN.
-
#disassociate_attribute_group(params = {}) ⇒ Types::DisassociateAttributeGroupResponse
Disassociates an attribute group from an application to remove the extra attributes contained in the attribute group from the application’s metadata.
-
#disassociate_resource(params = {}) ⇒ Types::DisassociateResourceResponse
Disassociates a resource from application.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves metadata information about one of your applications.
-
#get_associated_resource(params = {}) ⇒ Types::GetAssociatedResourceResponse
Gets the resource associated with the application.
-
#get_attribute_group(params = {}) ⇒ Types::GetAttributeGroupResponse
Retrieves an attribute group by its ARN, ID, or name.
-
#get_configuration(params = {}) ⇒ Types::GetConfigurationResponse
Retrieves a ‘TagKey` configuration from an account.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Retrieves a list of all of your applications.
-
#list_associated_attribute_groups(params = {}) ⇒ Types::ListAssociatedAttributeGroupsResponse
Lists all attribute groups that are associated with specified application.
-
#list_associated_resources(params = {}) ⇒ Types::ListAssociatedResourcesResponse
Lists all of the resources that are associated with the specified application.
-
#list_attribute_groups(params = {}) ⇒ Types::ListAttributeGroupsResponse
Lists all attribute groups which you have access to.
-
#list_attribute_groups_for_application(params = {}) ⇒ Types::ListAttributeGroupsForApplicationResponse
Lists the details of all attribute groups associated with a specific application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags on the resource.
-
#put_configuration(params = {}) ⇒ Struct
Associates a ‘TagKey` configuration to an account.
-
#sync_resource(params = {}) ⇒ Types::SyncResourceResponse
Syncs the resource with current AppRegistry records.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing application with new attributes.
-
#update_attribute_group(params = {}) ⇒ Types::UpdateAttributeGroupResponse
Updates an existing attribute group with new details.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appregistry/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1629 1630 1631 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1629 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1632 1633 1634 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1632 def errors_module Errors end |
Instance Method Details
#associate_attribute_group(params = {}) ⇒ Types::AssociateAttributeGroupResponse
Associates an attribute group with an application to augment the application’s metadata with the group’s attributes. This feature enables applications to be described with user-defined details that are machine-readable, such as third-party integrations.
510 511 512 513 |
# File 'lib/aws-sdk-appregistry/client.rb', line 510 def associate_attribute_group(params = {}, = {}) req = build_request(:associate_attribute_group, params) req.send_request() end |
#associate_resource(params = {}) ⇒ Types::AssociateResourceResponse
Associates a resource with an application. The resource can be specified by its ARN or name. The application can be specified by ARN, ID, or name.
**Minimum permissions**
You must have the following permissions to associate a resource using the ‘OPTIONS` parameter set to `APPLY_APPLICATION_TAG`.
-
‘tag:GetResources`
-
‘tag:TagResources`
You must also have these additional permissions if you don’t use the ‘AWSServiceCatalogAppRegistryFullAccess` policy. For more information, see [AWSServiceCatalogAppRegistryFullAccess] in the AppRegistry Administrator Guide.
-
‘resource-groups:AssociateResource`
-
‘cloudformation:UpdateStack`
-
‘cloudformation:DescribeStacks`
<note markdown=“1”> In addition, you must have the tagging permission defined by the Amazon Web Services service that creates the resource. For more information, see [TagResources] in the *Resource Groups Tagging API Reference*.
</note>
[1]: docs.aws.amazon.com/servicecatalog/latest/arguide/full.html [2]: docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_TagResources.html
590 591 592 593 |
# File 'lib/aws-sdk-appregistry/client.rb', line 590 def associate_resource(params = {}, = {}) req = build_request(:associate_resource, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1602 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppRegistry') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appregistry' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions.
651 652 653 654 |
# File 'lib/aws-sdk-appregistry/client.rb', line 651 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_attribute_group(params = {}) ⇒ Types::CreateAttributeGroupResponse
Creates a new attribute group as a container for user-defined attributes. This feature enables users to have full control over their cloud application’s metadata in a rich machine-readable format to facilitate integration with automated workflows and third-party tools.
717 718 719 720 |
# File 'lib/aws-sdk-appregistry/client.rb', line 717 def create_attribute_group(params = {}, = {}) req = build_request(:create_attribute_group, params) req.send_request() end |
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an application that is specified either by its application ID, name, or ARN. All associated attribute groups and resources must be disassociated from it before deleting an application.
752 753 754 755 |
# File 'lib/aws-sdk-appregistry/client.rb', line 752 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_attribute_group(params = {}) ⇒ Types::DeleteAttributeGroupResponse
Deletes an attribute group, specified either by its attribute group ID, name, or ARN.
788 789 790 791 |
# File 'lib/aws-sdk-appregistry/client.rb', line 788 def delete_attribute_group(params = {}, = {}) req = build_request(:delete_attribute_group, params) req.send_request() end |
#disassociate_attribute_group(params = {}) ⇒ Types::DisassociateAttributeGroupResponse
Disassociates an attribute group from an application to remove the extra attributes contained in the attribute group from the application’s metadata. This operation reverts ‘AssociateAttributeGroup`.
826 827 828 829 |
# File 'lib/aws-sdk-appregistry/client.rb', line 826 def disassociate_attribute_group(params = {}, = {}) req = build_request(:disassociate_attribute_group, params) req.send_request() end |
#disassociate_resource(params = {}) ⇒ Types::DisassociateResourceResponse
Disassociates a resource from application. Both the resource and the application can be specified either by ID or name.
**Minimum permissions**
You must have the following permissions to remove a resource that’s been associated with an application using the ‘APPLY_APPLICATION_TAG` option for [AssociateResource].
-
‘tag:GetResources`
-
‘tag:UntagResources`
You must also have the following permissions if you don’t use the ‘AWSServiceCatalogAppRegistryFullAccess` policy. For more information, see [AWSServiceCatalogAppRegistryFullAccess] in the AppRegistry Administrator Guide.
-
‘resource-groups:DisassociateResource`
-
‘cloudformation:UpdateStack`
-
‘cloudformation:DescribeStacks`
<note markdown=“1”> In addition, you must have the tagging permission defined by the Amazon Web Services service that creates the resource. For more information, see [UntagResources] in the *Resource Groups Tagging API Reference*.
</note>
[1]: docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_AssociateResource.html [2]: docs.aws.amazon.com/servicecatalog/latest/arguide/full.html [3]: docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_UntTagResources.html
899 900 901 902 |
# File 'lib/aws-sdk-appregistry/client.rb', line 899 def disassociate_resource(params = {}, = {}) req = build_request(:disassociate_resource, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves metadata information about one of your applications. The application can be specified by its ARN, ID, or name (which is unique within one account in one region at a given point in time). Specify by ARN or ID in automated workflows if you want to make sure that the exact same application is returned or a ‘ResourceNotFoundException` is thrown, avoiding the ABA addressing problem.
957 958 959 960 |
# File 'lib/aws-sdk-appregistry/client.rb', line 957 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_associated_resource(params = {}) ⇒ Types::GetAssociatedResourceResponse
Gets the resource associated with the application.
1025 1026 1027 1028 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1025 def get_associated_resource(params = {}, = {}) req = build_request(:get_associated_resource, params) req.send_request() end |
#get_attribute_group(params = {}) ⇒ Types::GetAttributeGroupResponse
Retrieves an attribute group by its ARN, ID, or name. The attribute group can be specified by its ARN, ID, or name.
1072 1073 1074 1075 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1072 def get_attribute_group(params = {}, = {}) req = build_request(:get_attribute_group, params) req.send_request() end |
#get_configuration(params = {}) ⇒ Types::GetConfigurationResponse
Retrieves a ‘TagKey` configuration from an account.
1091 1092 1093 1094 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1091 def get_configuration(params = {}, = {}) req = build_request(:get_configuration, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Retrieves a list of all of your applications. Results are paginated.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1136 1137 1138 1139 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1136 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_associated_attribute_groups(params = {}) ⇒ Types::ListAssociatedAttributeGroupsResponse
Lists all attribute groups that are associated with specified application. Results are paginated.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1181 1182 1183 1184 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1181 def list_associated_attribute_groups(params = {}, = {}) req = build_request(:list_associated_attribute_groups, params) req.send_request() end |
#list_associated_resources(params = {}) ⇒ Types::ListAssociatedResourcesResponse
Lists all of the resources that are associated with the specified application. Results are paginated.
<note markdown=“1”> If you share an application, and a consumer account associates a tag query to the application, all of the users who can access the application can also view the tag values in all accounts that are associated with it using this API.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1238 1239 1240 1241 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1238 def list_associated_resources(params = {}, = {}) req = build_request(:list_associated_resources, params) req.send_request() end |
#list_attribute_groups(params = {}) ⇒ Types::ListAttributeGroupsResponse
Lists all attribute groups which you have access to. Results are paginated.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1285 1286 1287 1288 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1285 def list_attribute_groups(params = {}, = {}) req = build_request(:list_attribute_groups, params) req.send_request() end |
#list_attribute_groups_for_application(params = {}) ⇒ Types::ListAttributeGroupsForApplicationResponse
Lists the details of all attribute groups associated with a specific application. The results display in pages.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1333 1334 1335 1336 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1333 def list_attribute_groups_for_application(params = {}, = {}) req = build_request(:list_attribute_groups_for_application, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags on the resource.
1362 1363 1364 1365 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1362 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_configuration(params = {}) ⇒ Struct
Associates a ‘TagKey` configuration to an account.
1388 1389 1390 1391 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1388 def put_configuration(params = {}, = {}) req = build_request(:put_configuration, params) req.send_request() end |
#sync_resource(params = {}) ⇒ Types::SyncResourceResponse
Syncs the resource with current AppRegistry records.
Specifically, the resource’s AppRegistry system tags sync with its associated application. We remove the resource’s AppRegistry system tags if it does not associate with the application. The caller must have permissions to read and update the resource.
1431 1432 1433 1434 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1431 def sync_resource(params = {}, = {}) req = build_request(:sync_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
Each tag consists of a key and an optional value. If a tag with the same key is already associated with the resource, this action updates its value.
This operation returns an empty response if the call was successful.
1465 1466 1467 1468 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1465 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
This operation returns an empty response if the call was successful.
1493 1494 1495 1496 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1493 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates an existing application with new attributes.
1540 1541 1542 1543 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1540 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_attribute_group(params = {}) ⇒ Types::UpdateAttributeGroupResponse
Updates an existing attribute group with new details.
1593 1594 1595 1596 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1593 def update_attribute_group(params = {}, = {}) req = build_request(:update_attribute_group, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1622 1623 1624 |
# File 'lib/aws-sdk-appregistry/client.rb', line 1622 def waiter_names [] end |